@@ -8,37 +8,40 @@
  * This is free software. See COPYING for details.
  */
 
-using System.Collections;
+using System;
+using System.Collections.Generic;
 
 namespace FSpot
 {
 	public class Category : Tag {
-		ArrayList children;
+		List<Tag> children;
 		bool children_need_sort;
-		public Tag [] Children {
+		public IList<Tag> Children {
 			get {
 				if (children_need_sort)
 					children.Sort ();
-				return (Tag []) children.ToArray (typeof (Tag));
+				return children.ToArray ();
 			}
 			set {
-				children = new ArrayList (value);
+				children = new List<Tag> (value);
 				children_need_sort = true;
 			}
 		}
 	
 		// Appends all of this categories descendents to the list
-		public void AddDescendentsTo (ArrayList list)
+		public void AddDescendentsTo (IList<Tag> list)
 		{
+			if (list == null)
+				throw new ArgumentNullException ("list");
+
 			foreach (Tag tag in children) {
 				if (! list.Contains (tag))
 					list.Add (tag);
 	
-				if (! (tag is Category))
-					continue;
-	
 				Category cat = tag as Category;
-	
+				if (cat == null)
+					continue;
+		
 				cat.AddDescendentsTo (list);
 			}
 		}
@@ -58,7 +61,7 @@ namespace FSpot
 		public Category (Category category, uint id, string name)
 			: base (category, id, name)
 		{
-			children = new ArrayList ();
+			children = new List<Tag> ();
 		}
 	}
 }
