@@ -14,19 +14,16 @@ using FSpot.Utils;
 
 namespace FSpot
 {
-	public class Tag : DbItem, IComparable, IDisposable {
-		private string name;
+	public class Tag : DbItem, IComparable<Tag>, IDisposable {
+		string name;
 		public string Name {
-			set {
-				name = value;
-			}
-			get {
-				return name;
-			}
+			get { return name; }
+			set {  name = value;}
 		}
 	
-		private Category category;
+		Category category;
 		public Category Category {
+			get { return category; }
 			set {
 				if (Category != null)
 					Category.RemoveChild (this);
@@ -35,46 +32,51 @@ namespace FSpot
 				if (category != null)
 					category.AddChild (this);
 			}
-			get {
-				return category;
-			}
 		}
 	
-		private int sort_priority;
+		int sort_priority;
 		public int SortPriority {
-			set { sort_priority = value; }
 			get { return sort_priority; }
+			set { sort_priority = value; }
 		}
 	
-		private int popularity = 0;
+		int popularity = 0;
 		public int Popularity {
 			get { return popularity; }
 			set { popularity = value; }
 		}
 
 		// Icon.  If theme_icon_name is not null, then we save the name of the icon instead
-		// of the actual icon data.
-	
-		private string theme_icon_name;
+		// of the actual icon data.	
+		string theme_icon_name;
 		public string ThemeIconName {
-			set {
-				theme_icon_name = value;
-				cached_icon_size = IconSize.Hidden;
-				icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, theme_icon_name, 48, (Gtk.IconLookupFlags)0);
-			}
 			get { return theme_icon_name; }
+			set { theme_icon_name = value; }
 		}
 	
-		private Pixbuf icon;
+		Pixbuf icon;
 		public Pixbuf Icon {
+			get {
+				if (icon == null && theme_icon_name != null) {
+					cached_icon_size = IconSize.Hidden;
+					icon = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, theme_icon_name, 48, (Gtk.IconLookupFlags)0);
+				}
+				return icon;
+			}
 			set {
 				theme_icon_name = null;
 				if (icon != null)
 					icon.Dispose ();
 				icon = value;
 				cached_icon_size = IconSize.Hidden;
+				IconWasCleared = value == null;
 			}
-			get { return icon; }
+		}
+
+		bool icon_was_cleared = false;
+		public bool IconWasCleared {
+			get { return icon_was_cleared; }
+			set { icon_was_cleared = value; }
 		}
 	
 		public enum IconSize {
@@ -84,13 +86,13 @@ namespace FSpot
 			Large = 48
 		};
 	
-		private static IconSize tag_icon_size = IconSize.Large;
+		static IconSize tag_icon_size = IconSize.Large;
 		public static IconSize TagIconSize {
 			get { return tag_icon_size; }
 			set { tag_icon_size = value; }
 		}
 	
-		private Pixbuf cached_icon;
+		Pixbuf cached_icon;
 		private IconSize cached_icon_size = IconSize.Hidden;
 	
 		// We can use a SizedIcon everywhere we were using an Icon
@@ -108,15 +110,17 @@ namespace FSpot
 					if (Math.Max (cached_icon.Width, cached_icon.Height) <= (int) tag_icon_size) 
 						return cached_icon;
 				}
-				if (Math.Max (icon.Width, icon.Height) >= (int) tag_icon_size) { //Don't upscale
+				if (Icon == null)
+					return null;
+
+				if (Math.Max (Icon.Width, Icon.Height) >= (int) tag_icon_size) { //Don't upscale
 					if (cached_icon != null)
 						cached_icon.Dispose ();
-					cached_icon = icon.ScaleSimple ((int) tag_icon_size, (int) tag_icon_size, InterpType.Bilinear);
+					cached_icon = Icon.ScaleSimple ((int) tag_icon_size, (int) tag_icon_size, InterpType.Bilinear);
 					cached_icon_size = tag_icon_size;
 					return cached_icon;
-				}
-				else
-					return icon;
+				} else
+					return Icon;
 			}	
 		}
 	
@@ -131,10 +135,11 @@ namespace FSpot
 	
 	
 		// IComparer.
-		public int CompareTo (object obj)
+		public int CompareTo (Tag tag)
 		{
-			Tag tag = obj as Tag;
-	
+			if (tag == null)
+				throw new ArgumentNullException ("tag");
+
 			if (Category == tag.Category) {
 				if (SortPriority == tag.SortPriority)
 					return Name.CompareTo (tag.Name);
@@ -147,6 +152,9 @@ namespace FSpot
 		
 		public bool IsAncestorOf (Tag tag)
 		{
+			if (tag == null)
+				throw new ArgumentNullException ("tag");
+
 			for (Category parent = tag.Category; parent != null; parent = parent.Category) {
 				if (parent == this)
 					return true;
@@ -168,7 +176,7 @@ namespace FSpot
 
 		~Tag ()
 		{
-			Log.DebugFormat ("Finalizer called on {0}. Should be Disposed", GetType ());		
+			Log.Debug ("Finalizer called on {0}. Should be Disposed", GetType ());		
 			if (icon != null)
 				icon.Dispose ();
 			if (cached_icon != null)
