@@ -1,4 +1,4 @@
-
+using FSpot.Utils;
 
 namespace FSpot {
 	public interface ILimitable {
@@ -13,7 +13,7 @@ namespace FSpot {
 			}
 		}
 
-		protected bool order_ascending = true;
+		protected bool order_ascending = false;
 		public bool OrderAscending {
 			get {
 				return order_ascending;
@@ -45,19 +45,19 @@ namespace FSpot {
 
 		protected void HandleQueryChanged (IBrowsableCollection sender)
 		{
-			System.Console.WriteLine ("Reloading" );
 			Reload ();
 		}
 
 		public void Dispose ()
 		{
-			this.query.PreChanged -= HandleQueryChanged; 
+			this.query.Changed -= HandleQueryChanged;
 		}
 
-		protected GroupAdaptor (PhotoQuery query)
+		protected GroupAdaptor (PhotoQuery query, bool order_ascending)
 		{
+			this.order_ascending = order_ascending;
 			this.query = query;
-			this.query.PreChanged += HandleQueryChanged;
+			this.query.Changed += HandleQueryChanged;
 
 			Reload (); 
 		}
