@@ -3,6 +3,7 @@
  *
  * Author(s):
  *	Larry Ewing  <lewing@novell.com>
+ *	Ruben Vermeersch  <ruben@savanne.be>
  *
  * This is free software, See COPYING for details.
  */
@@ -11,18 +12,36 @@ using System;
 
 namespace FSpot {
 	public class Histogram {
+#region Color hints
+		private byte [] colors = new byte [] {0x00, 0x00, 0x00, 0xff};
+
+		public byte RedColorHint {
+			set { colors [0] = value; }
+		}
+
+		public byte GreenColorHint {
+			set { colors [1] = value; }
+		}
+
+		public byte BlueColorHint {
+			set { colors [2] = value; }
+		}
+
+		public byte BackgroundColorHint {
+			set { colors [3] = value; }
+		}
+
+		private int [,] values = new int [256, 3];
+#endregion
+
 		public Histogram (Gdk.Pixbuf src)
 		{
 		        FillValues (src);
 		}
 		
 		public Histogram () {}
-		
-		// FIXME these should be properties
-		public byte [] Color = new byte [] {0x00, 0x00, 0x00, 0xff};
-
-		public void FillValues (Gdk.Pixbuf src)
 
+		private void FillValues (Gdk.Pixbuf src)
 		{
 			values = new int [256, 3];
 
@@ -54,24 +73,21 @@ namespace FSpot {
 					}
 				}
 			}
-			if (pixbuf != null) {
-				Draw (pixbuf);
-			}
 		}
 		
-		public int Count (int channel)
+		private int ChannelSum (int channel)
 		{
-			int count = 0;
+			int sum = 0;
 			for (int i = 0; i < values.GetLength (0); i++) {
-				count += values [i, channel];
+				sum += values [i, channel];
 			}
 
-			return count;
+			return sum;
 		}
 
 		public void GetHighLow (int channel, out int high, out int low)
 		{
-			double total = Count (channel);
+			double total = ChannelSum (channel);
 			double current = 0.0;
 			double percentage;
 			double next_percentage;
@@ -129,10 +145,10 @@ namespace FSpot {
 
 					int j = 0;
 					for (; j < height - top; j++) {
-						pixels [0] = Color [0];
-						pixels [1] = Color [1];
-						pixels [2] = Color [2];
-						pixels [3] = Color [3];
+						pixels [0] = colors [0];
+						pixels [1] = colors [1];
+						pixels [2] = colors [2];
+						pixels [3] = colors [3];
 						pixels += rowstride;
 					}
 					for (; j < height; j++) {
@@ -147,27 +163,23 @@ namespace FSpot {
 			}
 		}	
 
-		public Gdk.Pixbuf GeneratePixbuf ()
+		public Gdk.Pixbuf Generate (Gdk.Pixbuf input, int max_width)
 		{
+			Gdk.Pixbuf scaled;
+			using (Gdk.Pixbuf pixbuf = Generate (input))
+				scaled = PixbufUtils.ScaleToMaxSize (pixbuf, max_width, 128);
+			return scaled;
+		}
+
+		public Gdk.Pixbuf Generate (Gdk.Pixbuf input)
+		{
+			FillValues (input);
 			int height = 128;
-			pixbuf = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, true, 8, values.GetLength (0), height);
-			this.Draw (pixbuf);
+			Gdk.Pixbuf pixbuf = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, true, 8, values.GetLength (0), height);
+			Draw (pixbuf);
 			return pixbuf;
 		}
 						     
-		private int [,] values = new int [256, 3];
-		public int [,] Values {
-			get {
-				return values;
-			}
-		}
-		
-		private Gdk.Pixbuf pixbuf;
-		public Gdk.Pixbuf Pixbuf {
-			get {
-				return pixbuf;
-			}
-		}
 		
 #if FSPOT_HISTOGRAM_MAIN
 		public static void Main (string [] args) 
@@ -175,12 +187,12 @@ namespace FSpot {
 			Gtk.Application.Init ();
 			Gdk.Pixbuf pixbuf = new Gdk.Pixbuf (args [0]);
 			System.Console.WriteLine ("loaded {0}", args [0]);
-			Histogram hist = new Histogram (pixbuf);
+			Histogram hist = new Histogram ();
 			System.Console.WriteLine ("loaded histgram", args [0]);
 			
 			Gtk.Window win = new Gtk.Window ("display");
 			Gtk.Image image = new Gtk.Image ();
-			Gdk.Pixbuf img = hist.GeneratePixbuf ();
+			Gdk.Pixbuf img = hist.Generate (pixbuf);
 			image.Pixbuf = img;
 			win.Add (image);
 			win.ShowAll ();
