@@ -34,7 +34,7 @@ namespace FSpot.Jobs {
 			System.Threading.Thread.Sleep (500);
 			Console.WriteLine ("Syncing metadata to file...");
 			try {
-				Photo photo = FSpot.Core.Database.Photos.Get (Convert.ToUInt32 (JobOptions)) as Photo;
+				Photo photo = FSpot.App.Instance.Database.Photos.Get (Convert.ToUInt32 (JobOptions)) as Photo;
 				WriteMetadataToImage (photo);
 				return true;
 			} catch (System.Exception e) {
@@ -53,7 +53,7 @@ namespace FSpot.Jobs {
 					FSpot.JpegFile jimg = img as FSpot.JpegFile;
 				
 					jimg.SetDescription (photo.Description);
-					jimg.SetDateTimeOriginal (photo.Time.ToLocalTime ());
+					jimg.SetDateTimeOriginal (photo.Time);
 					jimg.SetXmp (UpdateXmp (photo, jimg.Header.GetXmp ()));
 	
 					jimg.SaveMetaData (path);
