@@ -229,14 +229,14 @@ public class PhotoStore : DbStore<Photo> {
 
 		while (reader.Read ()) {
 			uint tag_id = Convert.ToUInt32 (reader ["tag_id"]);
-			Tag tag = Core.Database.Tags.Get (tag_id) as Tag;
+			Tag tag = App.Instance.Database.Tags.Get (tag_id) as Tag;
 			photo.AddTagUnsafely (tag);
 		}
 		reader.Close();
 	}		
 	
-	private void GetAllVersions  () {
-		SqliteDataReader reader = Database.Query("SELECT photo_id, version_id, name, base_uri, filename, md5_sum, protected FROM photo_versions");
+	private void GetAllVersions  (string ids) {
+		SqliteDataReader reader = Database.Query ("SELECT photo_id, version_id, name, base_uri, filename, md5_sum, protected FROM photo_versions WHERE photo_id IN " + ids);
 		
 		while (reader.Read ()) {
 			uint id = Convert.ToUInt32 (reader ["photo_id"]);
@@ -272,8 +272,8 @@ public class PhotoStore : DbStore<Photo> {
 		reader.Close();
 	}
 
-	private void GetAllTags () {
-		SqliteDataReader reader = Database.Query("SELECT photo_id, tag_id FROM photo_tags");
+	private void GetAllTags (string ids) {
+		SqliteDataReader reader = Database.Query ("SELECT photo_id, tag_id FROM photo_tags WHERE photo_id IN " + ids);
 
 		while (reader.Read ()) {
 			uint id = Convert.ToUInt32 (reader ["photo_id"]);
@@ -289,9 +289,9 @@ public class PhotoStore : DbStore<Photo> {
 				continue;
 			}
 
-		        if (reader [1] != null) {
+			if (reader [1] != null) {
 				uint tag_id = Convert.ToUInt32 (reader ["tag_id"]);
-				Tag tag = Core.Database.Tags.Get (tag_id) as Tag;
+				Tag tag = App.Instance.Database.Tags.Get (tag_id) as Tag;
 				photo.AddTagUnsafely (tag);
 			}
 		}
@@ -443,7 +443,7 @@ public class PhotoStore : DbStore<Photo> {
 		Commit (photos);
 
 		foreach (Tag tag in tags)
-			Core.Database.Tags.Remove (tag);
+			App.Instance.Database.Tags.Remove (tag);
 		
 	}
 
@@ -892,19 +892,24 @@ public class PhotoStore : DbStore<Photo> {
 		reader.Close();
 
 		bool need_load = false;
+		string photo_ids = "(";
 		foreach (Photo photo in new_photos) {
 			AddToCache (photo);
+			photo_ids = photo_ids + Convert.ToString(photo.Id) + ",";
 			need_load |= !photo.Loaded;
 		}
 		
+		photo_ids = photo_ids + "-1)";
+	
 		if (need_load) {
-			GetAllTags ();
-			GetAllVersions ();
+			GetAllTags (photo_ids);
+			GetAllVersions (photo_ids);
 			foreach (Photo photo in new_photos)
 				photo.Loaded = true;
 		} else {
 			//Console.WriteLine ("Skipped Loading Data");
 		}
+	
 		foreach (Photo photo in new_photos)
 			photo.Changes = null;
 
@@ -1015,9 +1020,9 @@ public class PhotoStore : DbStore<Photo> {
 			where_clauses.Add (importidrange.SqlClause ());
 		}		
 		
-		if (hide && Core.Database.Tags.Hidden != null) {
+		if (hide && App.Instance.Database.Tags.Hidden != null) {
 			where_clauses.Add (String.Format ("id NOT IN (SELECT photo_id FROM photo_tags WHERE tag_id = {0})", 
-							  FSpot.Core.Database.Tags.Hidden.Id));
+							  App.Instance.Database.Tags.Hidden.Id));
 		}
 		
 		if (searchexpression != null) {
