@@ -17,23 +17,23 @@ namespace FSpot.Utils
 		public static DateTime DateTimeFromUnixTime (long unix_time)
 		{
 			DateTime date_time = new DateTime (1970, 1, 1);
-			return date_time.AddSeconds (unix_time).ToLocalTime ();
+			return date_time.AddSeconds (unix_time);
 		}
 	
 		public static long UnixTimeFromDateTime (DateTime date_time)
 		{
-			return (long) (date_time.ToUniversalTime () - new DateTime (1970, 1, 1)).TotalSeconds;
+			return (long) (date_time - new DateTime (1970, 1, 1)).TotalSeconds;
 		}
 #else
 		public static DateTime DateTimeFromUnixTime (long unix_time)
 		{
-			DateTime date_time = new DateTime (1970, 1, 1).ToLocalTime ();
+			DateTime date_time = new DateTime (1970, 1, 1);
 			return date_time.AddSeconds (unix_time);
 		}
 		
 		public static long UnixTimeFromDateTime (DateTime date_time)
 		{
-			return (long) (date_time - new DateTime (1970, 1, 1).ToLocalTime ()).TotalSeconds;
+			return (long) (date_time - new DateTime (1970, 1, 1)).TotalSeconds;
 		}
 #endif
 	}
