@@ -902,9 +902,9 @@ namespace FSpot.Widgets
 			if (DisplayDates) {
 				string date;
 				if (cell_width > 200) {
-					date = photo.Time.ToLocalTime ().ToString ();
+					date = photo.Time.ToString ();
 				} else {
-					date = photo.Time.ToLocalTime ().ToShortDateString ();
+					date = photo.Time.ToShortDateString ();
 				}
 
 				Pango.Layout layout = (Pango.Layout)date_layouts [date];
@@ -975,7 +975,7 @@ namespace FSpot.Widgets
 					Pixbuf icon = t.Icon;
 
 					Tag tag_iter = t.Category;
-					while (icon == null && tag_iter != Core.Database.Tags.RootCategory && tag_iter != null) {
+					while (icon == null && tag_iter != App.Instance.Database.Tags.RootCategory && tag_iter != null) {
 						icon = tag_iter.Icon;
 						tag_iter = tag_iter.Category;
 					}
