@@ -31,6 +31,11 @@ public class TagView : EventBox {
 		parent_tips = tips;
 	}
 
+	protected TagView (IntPtr raw) : base (raw)
+	{
+		VisibleWindow = false;	
+	}
+
 	public IBrowsableItem Current {
 		set {
 			photo = value;
@@ -90,6 +95,9 @@ public class TagView : EventBox {
 			} else {
 				scaled_icon = icon.ScaleSimple (thumbnail_size, thumbnail_size, InterpType.Bilinear);
 			}
+				Cms.Profile screen_profile;
+				if (FSpot.ColorManagement.Profiles.TryGetValue (Preferences.Get<string> (Preferences.COLOR_MANAGEMENT_DISPLAY_PROFILE), out screen_profile)) 
+					FSpot.ColorManagement.ApplyProfile (scaled_icon, screen_profile);
 
 			scaled_icon.RenderToDrawable (GdkWindow, Style.WhiteGC,
 						      0, 0, tag_x, tag_y, thumbnail_size, thumbnail_size,
